/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call;

import dk.vajhoej.record.Alignment;
import dk.vajhoej.record.Struct;

/**
 * Class IOSBX represents a VMS IOSB structure with a 4 byte status code.
 */
@Struct(alignment=Alignment.PACKED)
public class IOSBX extends IOSB {
	/**
	 * Construct new IOSBX.
	 */
	public IOSBX() {
		this(0, 0);
	}
	/**
	 * Construct new IOSBX.
	 * @param status status code
	 * @param any context specific information
	 */
	public IOSBX(int status, int any) {
		super(status & 0xFFFF, status >> 16, 0);
	}
	/**
	 * Get status.
	 * @return status code
	 */
	public int getStatus() {
		return (super.getCount() << 16) | super.getStatus();
	}
}
