/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call;

import dk.vajhoej.record.Alignment;
import dk.vajhoej.record.ArrayField;
import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class LKSB represents a VMS LKSB structure.
 */
@Struct(alignment=Alignment.PACKED)
public class LKSB {
	@StructField(n=0,type=FieldType.INT2)
	private int status;
	@StructField(n=1,type=FieldType.INT2)
	private int reserved;
	@StructField(n=2,type=FieldType.INT4)
	private int id;
	@ArrayField(elements=64)
	@StructField(n=3,type=FieldType.INT1)
	private byte[] valblk;
	/**
	 * Construct new IOSB.
	 */
	public LKSB() {
		this(0, 0);
	}
	/**
	 * Construct new LKSB.
	 * @param status status code
	 * @param id lock ID
	 */
	public LKSB(int status, int id) {
		this.status = status;
		this.reserved = 0;
		this.id = id;
		this.valblk = new byte[64];
	}
	/**
	 * Get status.
	 * @return status code
	 */
	public int getStatus() {
		return status;
	}
	/**
	 * Get lock ID.
	 * @return lock ID
	 */
	public int getId() {
		return id;
	}
}
